<img width="250" align="right" alt="Logo copia (goat's head)" src="https://user-images.githubusercontent.com/4376879/115404130-5167a480-a1ed-11eb-96fe-46116ee5971f.png">

# Copia
## Estimating the survival of cultural heritage artifacts with unseen species models from ecology 

Copia is a Python package that can be used for estimating the survival of artifacts from
cultural heritage, based on established unseen species models from ecology. 

## Installation

Copia requires Python 3.6 or greater. To install Copia, execute the following command in
your terminal: 

``` bash
pip install copia
```

## Development
If you wish to help developing Copia, download the source files from GitHub and install
the package using the following command: 

``` bash
pip install -e . 
```

in the top directory of `copia`.

Subsequently, run `pytest` from the same directory. 

## Documentation

For detailed documentation, visit
[copia.readthedocs.io](https://copia.readthedocs.io/en/latest/index.html). 

## Etymology
Because this package targets so-called "abundance" data from ecology, it has been named
using the corresponding Latin term *copia*. The artwork for the logo has been kindly
contributed by Dr. Lauren Fonteyn (Leiden University, NL). The depicted goat is a
mythological reference to the [cornucopia](https://en.wikipedia.org/wiki/Cornucopia) or
"horn of plenty", the legendary horn of the goat Amaltheia, who fed the infant Zeus with
her milk. 

## Maintainers
Mike Kestemont & Folgert Karsdorp
